DEFAULT = 10

DICT_STYLE_OVERRIDE = False

PREFIX_STYLE_OVERRIDE = False

APP_MODULE = "tests.mocks.app_test_imports.TestClass"

MULTIPLE_APP_MODULES = (
    "tests.mocks.app_test_imports.TestClass",
    "tests.mocks.app_test_imports.OtherTestClass"
)

NON_EXISTENT_APP_MODULE = "tests.mocks.app_test_imports.DoesNotExist"
